@@ -343,7 +343,8 @@ class DatabaseMigrationServiceClient(BaseClient):
         KmsKeyId: str = ...,
         PubliclyAccessible: bool = ...,
         DnsNameServers: str = ...,
-        ResourceIdentifier: str = ...
+        ResourceIdentifier: str = ...,
+        NetworkType: str = ...
     ) -> CreateReplicationInstanceResponseTypeDef:
         """
         Creates the replication instance using the specified parameters.
@@ -916,7 +917,8 @@ class DatabaseMigrationServiceClient(BaseClient):
         EngineVersion: str = ...,
         AllowMajorVersionUpgrade: bool = ...,
         AutoMinorVersionUpgrade: bool = ...,
-        ReplicationInstanceIdentifier: str = ...
+        ReplicationInstanceIdentifier: str = ...,
+        NetworkType: str = ...
     ) -> ModifyReplicationInstanceResponseTypeDef:
         """
         Modifies the replication instance to apply new settings.
