@@ -47,8 +47,7 @@ import sys
 from datetime import datetime
 from typing import Generic, Iterator, Sequence, TypeVar, Union
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     DescribeCertificatesResponseTypeDef,
@@ -101,7 +100,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class DescribeCertificatesPaginator(Boto3Paginator):
+class DescribeCertificatesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeCertificates)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describecertificatespaginator)
@@ -119,7 +118,7 @@ class DescribeCertificatesPaginator(Boto3Paginator):
         """
 
 
-class DescribeConnectionsPaginator(Boto3Paginator):
+class DescribeConnectionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeConnections)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describeconnectionspaginator)
@@ -137,7 +136,7 @@ class DescribeConnectionsPaginator(Boto3Paginator):
         """
 
 
-class DescribeEndpointTypesPaginator(Boto3Paginator):
+class DescribeEndpointTypesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeEndpointTypes)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describeendpointtypespaginator)
@@ -155,7 +154,7 @@ class DescribeEndpointTypesPaginator(Boto3Paginator):
         """
 
 
-class DescribeEndpointsPaginator(Boto3Paginator):
+class DescribeEndpointsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeEndpoints)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describeendpointspaginator)
@@ -173,7 +172,7 @@ class DescribeEndpointsPaginator(Boto3Paginator):
         """
 
 
-class DescribeEventSubscriptionsPaginator(Boto3Paginator):
+class DescribeEventSubscriptionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeEventSubscriptions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describeeventsubscriptionspaginator)
@@ -192,7 +191,7 @@ class DescribeEventSubscriptionsPaginator(Boto3Paginator):
         """
 
 
-class DescribeEventsPaginator(Boto3Paginator):
+class DescribeEventsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeEvents)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describeeventspaginator)
@@ -216,7 +215,7 @@ class DescribeEventsPaginator(Boto3Paginator):
         """
 
 
-class DescribeOrderableReplicationInstancesPaginator(Boto3Paginator):
+class DescribeOrderableReplicationInstancesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeOrderableReplicationInstances)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describeorderablereplicationinstancespaginator)
@@ -231,7 +230,7 @@ class DescribeOrderableReplicationInstancesPaginator(Boto3Paginator):
         """
 
 
-class DescribeReplicationInstancesPaginator(Boto3Paginator):
+class DescribeReplicationInstancesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeReplicationInstances)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describereplicationinstancespaginator)
@@ -249,7 +248,7 @@ class DescribeReplicationInstancesPaginator(Boto3Paginator):
         """
 
 
-class DescribeReplicationSubnetGroupsPaginator(Boto3Paginator):
+class DescribeReplicationSubnetGroupsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeReplicationSubnetGroups)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describereplicationsubnetgroupspaginator)
@@ -267,7 +266,7 @@ class DescribeReplicationSubnetGroupsPaginator(Boto3Paginator):
         """
 
 
-class DescribeReplicationTaskAssessmentResultsPaginator(Boto3Paginator):
+class DescribeReplicationTaskAssessmentResultsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeReplicationTaskAssessmentResults)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describereplicationtaskassessmentresultspaginator)
@@ -282,7 +281,7 @@ class DescribeReplicationTaskAssessmentResultsPaginator(Boto3Paginator):
         """
 
 
-class DescribeReplicationTasksPaginator(Boto3Paginator):
+class DescribeReplicationTasksPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeReplicationTasks)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describereplicationtaskspaginator)
@@ -301,7 +300,7 @@ class DescribeReplicationTasksPaginator(Boto3Paginator):
         """
 
 
-class DescribeSchemasPaginator(Boto3Paginator):
+class DescribeSchemasPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeSchemas)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describeschemaspaginator)
@@ -316,7 +315,7 @@ class DescribeSchemasPaginator(Boto3Paginator):
         """
 
 
-class DescribeTableStatisticsPaginator(Boto3Paginator):
+class DescribeTableStatisticsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeTableStatistics)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/paginators/#describetablestatisticspaginator)
