@@ -1239,6 +1239,10 @@ TableStatisticsTypeDef = TypedDict(
         "Deletes": int,
         "Updates": int,
         "Ddls": int,
+        "AppliedInserts": int,
+        "AppliedDeletes": int,
+        "AppliedUpdates": int,
+        "AppliedDdls": int,
         "FullLoadRows": int,
         "FullLoadCondtnlChkFailedRows": int,
         "FullLoadErrorRows": int,
@@ -1309,6 +1313,7 @@ _OptionalModifyReplicationInstanceMessageRequestTypeDef = TypedDict(
         "AllowMajorVersionUpgrade": bool,
         "AutoMinorVersionUpgrade": bool,
         "ReplicationInstanceIdentifier": str,
+        "NetworkType": str,
     },
     total=False,
 )
@@ -1448,6 +1453,7 @@ ReplicationPendingModifiedValuesTypeDef = TypedDict(
         "AllocatedStorage": int,
         "MultiAZ": bool,
         "EngineVersion": str,
+        "NetworkType": str,
     },
     total=False,
 )
@@ -1642,6 +1648,7 @@ _OptionalCreateReplicationInstanceMessageRequestTypeDef = TypedDict(
         "PubliclyAccessible": bool,
         "DnsNameServers": str,
         "ResourceIdentifier": str,
+        "NetworkType": str,
     },
     total=False,
 )
@@ -2757,6 +2764,7 @@ ReplicationSubnetGroupTypeDef = TypedDict(
         "VpcId": str,
         "SubnetGroupStatus": str,
         "Subnets": List[SubnetTypeDef],
+        "SupportedNetworkTypes": List[str],
     },
     total=False,
 )
@@ -2983,10 +2991,12 @@ ReplicationInstanceTypeDef = TypedDict(
         "ReplicationInstancePrivateIpAddress": str,
         "ReplicationInstancePublicIpAddresses": List[str],
         "ReplicationInstancePrivateIpAddresses": List[str],
+        "ReplicationInstanceIpv6Addresses": List[str],
         "PubliclyAccessible": bool,
         "SecondaryAvailabilityZone": str,
         "FreeUntil": datetime,
         "DnsNameServers": str,
+        "NetworkType": str,
     },
     total=False,
 )
